@@ -8,7 +8,6 @@
 #include "ldapdn.h"
 
 #include "ldap_debug.h"
-#include <QRegularExpression>
 #include <algorithm>
 
 using namespace KLDAP;
@@ -17,7 +16,6 @@ class Q_DECL_HIDDEN LdapDN::LdapDNPrivate
 {
 public:
     LdapDNPrivate()
-        : m_dn()
     {
     }
 
@@ -25,8 +23,8 @@ public:
     {
     }
 
-    bool isValidRDNString(const QString &rdn) const;
-    QStringList splitOnNonEscapedChar(const QString &rdn, QChar ch) const;
+    Q_REQUIRED_RESULT bool isValidRDNString(const QString &rdn) const;
+    Q_REQUIRED_RESULT QStringList splitOnNonEscapedChar(const QString &rdn, QChar ch) const;
 
     QString m_dn;
 };
@@ -46,12 +44,8 @@ bool LdapDN::LdapDNPrivate::isValidRDNString(const QString &rdn) const
         }
         return true;
     }
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 2)
-    const QVector<QStringRef> components = rdn.splitRef(QLatin1Char('='));
-#else
     // Split the rdn into the attribute name and value parts
     const auto components = QStringView(rdn).split(QLatin1Char('='));
-#endif
     // We should have exactly two parts
     if (components.size() != 2) {
         return false;
@@ -80,7 +74,7 @@ QStringList LdapDN::LdapDNPrivate::splitOnNonEscapedChar(const QString &str, QCh
         searchFrom = index + 1;
     }
 
-    // Add on the part after the last found delimeter
+    // Add on the part after the last found delimiter
     QString tmp = str.mid(strPartStartIndex);
     // qCDebug(LDAP_LOG) << "Adding part:" << tmp;
     strParts.append(tmp);
@@ -115,10 +109,7 @@ LdapDN &LdapDN::operator=(const LdapDN &that)
     return *this;
 }
 
-LdapDN::~LdapDN()
-{
-    delete d;
-}
+LdapDN::~LdapDN() = default;
 
 void LdapDN::clear()
 {
