@@ -6,8 +6,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef ADDHOSTDIALOG_H
-#define ADDHOSTDIALOG_H
+#pragma once
 
 #include "kldap_export.h"
 #include <QDialog>
@@ -26,7 +25,7 @@ class KLDAP_EXPORT AddHostDialog : public QDialog
 
 public:
     explicit AddHostDialog(KLDAP::LdapServer *server, QWidget *parent = nullptr);
-    ~AddHostDialog();
+    ~AddHostDialog() override;
 
 Q_SIGNALS:
     void changed(bool);
@@ -36,8 +35,7 @@ private Q_SLOTS:
     void slotOk();
 
 private:
-    AddHostDialogPrivate *const d;
+    std::unique_ptr<AddHostDialogPrivate> const d;
 };
 }
 
-#endif // ADDHOSTDIALOG_H
