@@ -9,21 +9,18 @@
 #include <kldap/ldapserver.h>
 
 #include <KConfig>
-#include <KConfigGroup>
-#include <KLocalizedString>
-#include <KMessageBox>
 #include <qt5keychain/keychain.h>
 using namespace QKeychain;
 using namespace KLDAP;
 
-class Q_DECL_HIDDEN LdapClientSearchConfig::Private
+class Q_DECL_HIDDEN LdapClientSearchConfig::LdapClientSearchConfigPrivate
 {
 public:
-    Private()
+    LdapClientSearchConfigPrivate()
     {
     }
 
-    ~Private()
+    ~LdapClientSearchConfigPrivate()
     {
     }
 };
@@ -37,14 +34,12 @@ KConfig *LdapClientSearchConfig::config()
 
 LdapClientSearchConfig::LdapClientSearchConfig(QObject *parent)
     : QObject(parent)
-    , d(new LdapClientSearchConfig::Private())
+    , d(new LdapClientSearchConfig::LdapClientSearchConfigPrivate())
 {
 }
 
-LdapClientSearchConfig::~LdapClientSearchConfig()
-{
-    delete d;
-}
+LdapClientSearchConfig::~LdapClientSearchConfig() = default;
+
 #if 0 // Port it
 void LdapClientSearchConfig::clearWalletPassword()
 {
