@@ -5,7 +5,6 @@
  */
 
 #include "ldapconfigurewidget.h"
-#include <QGroupBox>
 #include <QLabel>
 #include <QListWidget>
 #include <QListWidgetItem>
@@ -33,8 +32,8 @@ using namespace KLDAP;
 
 LdapConfigureWidget::LdapConfigureWidget(QWidget *parent)
     : QWidget(parent)
+    , mClientSearchConfig(new KLDAP::LdapClientSearchConfig)
 {
-    mClientSearchConfig = new KLDAP::LdapClientSearchConfig;
     initGUI();
 
     connect(mHostListView, &QListWidget::currentItemChanged, this, &LdapConfigureWidget::slotSelectionChanged);
@@ -110,8 +109,12 @@ void LdapConfigureWidget::slotRemoveHost()
         return;
     }
     auto ldapItem = dynamic_cast<LdapWidgetItem *>(item);
-    if (KMessageBox::No
-        == KMessageBox::questionYesNo(this, i18n("Do you want to remove setting for host \"%1\"?", ldapItem->server().host()), i18n("Remove Host"))) {
+    const int answer = KMessageBox::questionYesNo(this,
+                                                  i18n("Do you want to remove setting for host \"%1\"?", ldapItem->server().host()),
+                                                  i18n("Remove Host"),
+                                                  KStandardGuiItem::remove(),
+                                                  KStandardGuiItem::cancel());
+    if (answer == KMessageBox::No) {
         return;
     }
 
@@ -261,15 +264,9 @@ void LdapConfigureWidget::save()
 
 void LdapConfigureWidget::initGUI()
 {
-    auto layout = new QVBoxLayout(this);
-    layout->setObjectName(QStringLiteral("layout"));
-    layout->setContentsMargins(0, 0, 0, 0);
-
-    auto groupBox = new QGroupBox(i18n("LDAP Servers"));
-    layout->addWidget(groupBox);
-    auto mainLayout = new QVBoxLayout;
-    mainLayout->setObjectName(QStringLiteral("mainlayout"));
-    groupBox->setLayout(mainLayout);
+    auto mainLayout = new QVBoxLayout(this);
+    mainLayout->setObjectName(QStringLiteral("layout"));
+    mainLayout->setContentsMargins(5, 5, 5, 5);
 
     // Contents of the QVGroupBox: label and hbox
     auto label = new QLabel(i18n("Check all servers that should be used:"));
@@ -314,7 +311,6 @@ void LdapConfigureWidget::initGUI()
     mRemoveButton = buttons->addButton(i18n("&Remove Host"), QDialogButtonBox::ActionRole);
     connect(mRemoveButton, &QPushButton::clicked, this, &LdapConfigureWidget::slotRemoveHost);
     mRemoveButton->setEnabled(false);
-    buttons->layout();
 
-    layout->addWidget(buttons);
+    mainLayout->addWidget(buttons);
 }
