@@ -27,7 +27,7 @@ class KLDAP_EXPORT LdapConfigureWidget : public QWidget
     Q_OBJECT
 public:
     explicit LdapConfigureWidget(QWidget *parent = nullptr);
-    ~LdapConfigureWidget();
+    ~LdapConfigureWidget() override;
 
     void load();
     void save();
@@ -55,7 +55,7 @@ private:
 
     QToolButton *mUpButton = nullptr;
     QToolButton *mDownButton = nullptr;
-    KLDAP::LdapClientSearchConfig *mClientSearchConfig = nullptr;
+    KLDAP::LdapClientSearchConfig *const mClientSearchConfig;
 };
 }
 
